{% extends 'wagtailadmin/reports/base_report.html' %} {% load i18n wagtailadmin_tags %} {% block titletag %}{% blocktrans trimmed with title=subtitle %}Snippet history for {{ subtitle }}{% endblocktrans %}{% endblock %} {% block bodyclass %}model-{{ model_opts.model_name }}{% endblock %} {% block actions %} {% trans "Edit this snippet" %} {% endblock %} {% block content %} {% include 'wagtailsnippets/snippets/headers/history_header.html' %} {{ block.super }} {% endblock %} {% block results %} {% if object_list %} {% component table %} {% else %}

{% trans "No log entries found." %}

{% endif %} {% endblock %}